==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/admin/includes/languages/english/record_company.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: record_company.php,v 1.1.1.1 2004/09/01 04:47:10 shidairiki Exp $
//
  define('HEADING_TITLE', 'Record Companies');
  define('TABLE_HEADING_RECORD_COMPANY', 'Record Company');
  define('TABLE_HEADING_ACTION', 'Action');
  define('TEXT_NEW_INTRO', 'Please enter the details of the new Record Company below.');
  define('TEXT_EDIT_INTRO', 'Please amend the details of the Record Company below.');
  define('TEXT_DELETE_INTRO', 'Are you sure you want to delete this Record Company.');
  define('TEXT_DELETE_IMAGE', 'Delete Image?.');
  define('TEXT_RECORD_COMPANY_NAME', 'Record Company Name');
  define('TEXT_RECORD_COMPANY_IMAGE', 'Record Company Image');
  define('TEXT_RECORD_COMPANY_URL', 'Record Company Web Site');
  define('TEXT_RECORD_COMPANY_IMAGE_DIR', 'Image Directory&nbsp;');

  define('TEXT_HEADING_NEW_RECORD_COMPANY', 'New Record Company');
  define('TEXT_HEADING_EDIT_RECORD_COMPANY', 'Edit Record Company');
  define('TEXT_HEADING_DELETE_RECORD_COMPANY', 'Delete Record Company');
  define('TEXT_DATE_ADDED', 'Date Added');
  define('TEXT_LAST_MODIFIED', 'Date Modified');
  define('TEXT_IMAGE_NONEXISTENT', 'Image does not exist');
  define('TEXT_PRODUCTS', 'Linked Products');
  define('TEXT_DISPLAY_NUMBER_OF_RECORD_COMPANIES', 'Displaying <strong>%d</strong> to <strong>%d</strong> (of <strong>%d</strong> Record Companies)');

?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/admin/includes/languages/english/record_company.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: record_company.php 276 2004-09-10 22:35:28Z wilt $
//
  define('HEADING_TITLE', 'Record Companies');
  define('TABLE_HEADING_RECORD_COMPANY', 'Record Company');
  define('TABLE_HEADING_ACTION', 'Action');
  define('TEXT_NEW_INTRO', 'Please enter the details of the new Record Company below.');
  define('TEXT_EDIT_INTRO', 'Please amend the details of the Record Company below.');
  define('TEXT_DELETE_INTRO', 'Are you sure you want to delete this Record Company.');
  define('TEXT_DELETE_IMAGE', 'Delete Image?.');
  define('TEXT_RECORD_COMPANY_NAME', 'Record Company Name');
  define('TEXT_RECORD_COMPANY_IMAGE', 'Record Company Image');
  define('TEXT_RECORD_COMPANY_URL', 'Record Company Web Site');
  define('TEXT_RECORD_COMPANY_IMAGE_DIR', 'Image Directory&nbsp;');

  define('TEXT_HEADING_NEW_RECORD_COMPANY', 'New Record Company');
  define('TEXT_HEADING_EDIT_RECORD_COMPANY', 'Edit Record Company');
  define('TEXT_HEADING_DELETE_RECORD_COMPANY', 'Delete Record Company');
  define('TEXT_DATE_ADDED', 'Date Added');
  define('TEXT_LAST_MODIFIED', 'Date Modified');
  define('TEXT_IMAGE_NONEXISTENT', 'Image does not exist');
  define('TEXT_PRODUCTS', 'Linked Products');
  define('TEXT_DISPLAY_NUMBER_OF_RECORD_COMPANIES', 'Displaying <strong>%d</strong> to <strong>%d</strong> (of <strong>%d</strong> Record Companies)');
  define('TEXT_DELETE_PRODUCTS', 'Delete this Record Company and all items linked to it?');
  define('TEXT_DELETE_WARNING_PRODUCTS', '<b>WARNING:</b> There are %s items still linked to this Record Company!');
?>
